@@ -5,23 +5,49 @@
 # do its job correctly.
 
 import sys, string, fnmatch
+import re
+
+import_pat = re.compile(r'\s*import\s+(\S+)\.([^\s.]+)\s+as\s+(\S+)')
 
 class Overrides:
-    def __init__(self, fp=sys.stdin):
+    def __init__(self, filename=None):
 	self.ignores = {}
 	self.glob_ignores = []
 	self.overrides = {}
 	self.kwargs = {}
+        self.startlines = {}
         self.override_attrs = {}
         self.headers = ''
         self.init = ''
-	if fp == None: return
+        self.imports = []
+	if filename: self.__handle_file(filename)
+
+    def __handle_file(self, filename):
+        fp = open(filename, 'r')
 	# read all the components of the file ...
-	bufs = map(string.strip, string.split(fp.read(), '%%'))
-	if bufs == ['']: return
-	for buf in bufs:
-	    self.__parse_override(buf)
-    def __parse_override(self, buffer):
+        bufs = []
+        startline = 1
+        lines = []
+        line = fp.readline()
+        linenum = 1
+        while line:
+            if line == '%%\n' or line == '%%':
+                if lines:
+                    bufs.append((string.join(lines, ''), startline))
+                startline = linenum + 1
+                lines = []
+            else:
+                lines.append(line)
+            line = fp.readline()
+            linenum = linenum + 1
+        if lines:
+            bufs.append((string.join(lines, ''), startline))
+	if not bufs: return
+
+	for buf, startline in bufs:
+	    self.__parse_override(buf, startline, filename)
+
+    def __parse_override(self, buffer, startline, filename):
 	pos = string.find(buffer, '\n')
 	if pos >= 0:
 	    line = buffer[:pos]
@@ -41,13 +67,22 @@ class Overrides:
 	    if 'kwargs' in words[1:]:
 		self.kwargs[func] = 1
 	    self.overrides[func] = rest
+            self.startlines[func] = (startline + 1, filename)
         elif words[0] == 'override-attr':
             attr = words[1]
             self.override_attrs[attr] = rest
+            self.startlines[attr] = (startline + 1, filename)
         elif words[0] == 'headers':
-            self.headers = self.headers + '\n' + rest
+            self.headers = '%s\n#line %d "%s"\n%s' % \
+                           (self.headers, startline + 1, filename, rest)
         elif words[0] == 'init':
-            self.init = self.init + '\n' + rest
+            self.init = '%s\n#line %d "%s"\n%s' % \
+                        (self.init, startline + 1, filename, rest)
+        elif words[0] == 'import':
+            for line in string.split(buffer, '\n'):
+                match = import_pat.match(line)
+                if match:
+                    self.imports.append(match.groups())
 
     def is_ignored(self, name):
 	if self.ignores.has_key(name):
@@ -60,6 +95,8 @@ class Overrides:
 	return self.overrides.has_key(name)
     def override(self, name):
 	return self.overrides[name]
+    def getstartline(self, name):
+        return self.startlines[name]
     def wants_kwargs(self, name):
 	return self.kwargs.has_key(name)
     def attr_is_overriden(self, attr):
@@ -70,3 +107,5 @@ class Overrides:
         return self.headers
     def get_init(self):
         return self.init
+    def get_imports(self):
+        return self.imports
